import { Myo } from "./Myo";
import { IMyoDto, ICommand, LockingPolicy, MMEvent, Pose, MMPoseOffEvent, EMGPodsTuple, MMStatusEvent, MCBCloseEvent, MCBOrientation, MCBAcceleration, MCBGyroscope, MCBIMU, MCBStatus, MCBBatteryLevel, MCBRSSI, MCBBluetoothStrength, MCBEMG, MCBEmpty, MCBPose, MCBEvent } from "./types";
import { Quaternion, Vector3, IIMUData } from "./util";
export declare class MyoManager {
    private defaults;
    private eventHandlers;
    private eventHandlersAll;
    private eventCounter;
    lockingPolicy: LockingPolicy;
    myos: Myo[];
    private socket;
    private onError();
    setLockingPolicy(policy: LockingPolicy): void;
    emit(name: MMEvent.Ready, myo: undefined, ev: Event): void;
    emit(name: MMEvent.SocketClosed, myo: undefined, ev: CloseEvent): void;
    emit(name: Pose | MMPoseOffEvent, myo: Myo): void;
    emit(name: MMEvent.PoseEnter | MMEvent.PoseLeave, myo: Myo, pose: Pose): void;
    emit(name: MMEvent.Orientation, myo: Myo, orientation: Quaternion, t: number): void;
    emit(name: MMEvent.Accelerometer, myo: Myo, acceleration: Vector3, t: number): void;
    emit(name: MMEvent.Gyroscope, myo: Myo, gyroscope: Vector3, t: number): void;
    emit(name: MMEvent.IMU, myo: Myo, imuData: IIMUData, t: number): void;
    emit(name: MMEvent.ZeroOrientation, myo: Myo): void;
    emit(name: MMEvent.EMG, myo: Myo, emg: EMGPodsTuple, t: number): void;
    emit(name: MMEvent.BluetoothStrength, myo: Myo, strength: number, t: number): void;
    emit(name: MMEvent.RSSI, myo: Myo, rssi: number, t: number): void;
    emit(name: MMEvent.BatteryLevel, myo: Myo, level: number, t: number): void;
    emit(name: MMStatusEvent, myo: Myo, data: IMyoDto, t: number): void;
    on(name: "ready", fn: MCBEvent): void;
    on(name: "socket_closed", fn: MCBCloseEvent): void;
    on(name: "rest" | "rest_off" | "fingers_spread" | "fingers_spread_off" | "wave_in" | "wave_in_off" | "wave_out" | "wave_out_off" | "fist" | "fist_off" | "double_tap" | "double_tap_off" | "zero_orientation", fn: MCBEmpty): void;
    on(name: "pose" | "pose_off", fn: MCBPose): void;
    on(name: "orientation", fn: MCBOrientation): void;
    on(name: "accelerometer", fn: MCBAcceleration): void;
    on(name: "gyroscope", fn: MCBGyroscope): void;
    on(name: "imu", fn: MCBIMU): void;
    on(name: "emg", fn: MCBEMG): void;
    on(name: "bluetooth_strength", fn: MCBBluetoothStrength): void;
    on(name: "rssi", fn: MCBRSSI): void;
    on(name: "battery_level", fn: MCBBatteryLevel): void;
    on(name: "status" | "warmup_complete" | "paired" | "disconnected" | "connected" | "locked" | "arm_synced" | "arm_unsynced", fn: MCBStatus): void;
    off(name: string): void;
    connect(newAppID?: string, newSocketURL?: string): void;
    disconnect(): void;
    sendCommand(data: ICommand): void;
    private handleMessage(msg);
}
