"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
function clamp(val, min, max) {
    return Math.min(Math.max(min, val), max);
}
exports.clamp = clamp;
function getStrengthFromRssi(rssi) {
    // tslint:disable:no-magic-numbers
    const min = -95;
    const max = -40;
    const percent = 100;
    // tslint:enable:no-magic-numbers
    rssi = clamp(rssi, min, max);
    return Math.round((rssi - min) * percent / (max - min) * percent) / percent;
}
exports.getStrengthFromRssi = getStrengthFromRssi;
class Quaternion {
    constructor(x, y, z, w) {
        this.x = x;
        this.y = y;
        this.z = z;
        this.w = w;
    }
    invert() {
        const { x, y, z, w } = this;
        const len = Math.sqrt(x * x + y * y + z * z + w * w);
        return {
            w: w / len,
            x: -x / len,
            y: -y / len,
            z: -z / len
        };
    }
    rotate(r) {
        const { x, y, z, w } = this;
        return {
            w: w * r.w - x * r.x - y * r.y - z * r.z,
            x: w * r.x + x * r.w + y * r.z - z * r.y,
            y: w * r.y - x * r.z + y * r.w + z * r.x,
            z: w * r.z + x * r.y - y * r.x + z * r.w
        };
    }
    static Identity() {
        return new Quaternion(0, 0, 0, 1);
    }
}
exports.Quaternion = Quaternion;
class Vector3 {
    constructor(x, y, z) {
        this.x = x;
        this.y = y;
        this.z = z;
    }
    static fromArray(a) {
        return new Vector3(a[0], a[1], a[2]); // tslint:disable-line:no-magic-numbers
    }
}
exports.Vector3 = Vector3;
//# sourceMappingURL=util.js.map